@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import ApplicationStatusType, InputStartingPositionType, RecordFormatTypeType
 
@@ -194,11 +194,11 @@ ApplicationSummaryTypeDef = TypedDict(
 ApplicationUpdateTypeDef = TypedDict(
     "ApplicationUpdateTypeDef",
     {
-        "InputUpdates": List["InputUpdateTypeDef"],
+        "InputUpdates": Sequence["InputUpdateTypeDef"],
         "ApplicationCodeUpdate": str,
-        "OutputUpdates": List["OutputUpdateTypeDef"],
-        "ReferenceDataSourceUpdates": List["ReferenceDataSourceUpdateTypeDef"],
-        "CloudWatchLoggingOptionUpdates": List["CloudWatchLoggingOptionUpdateTypeDef"],
+        "OutputUpdates": Sequence["OutputUpdateTypeDef"],
+        "ReferenceDataSourceUpdates": Sequence["ReferenceDataSourceUpdateTypeDef"],
+        "CloudWatchLoggingOptionUpdates": Sequence["CloudWatchLoggingOptionUpdateTypeDef"],
     },
     total=False,
 )
@@ -274,11 +274,11 @@ _OptionalCreateApplicationRequestRequestTypeDef = TypedDict(
     "_OptionalCreateApplicationRequestRequestTypeDef",
     {
         "ApplicationDescription": str,
-        "Inputs": List["InputTypeDef"],
-        "Outputs": List["OutputTypeDef"],
-        "CloudWatchLoggingOptions": List["CloudWatchLoggingOptionTypeDef"],
+        "Inputs": Sequence["InputTypeDef"],
+        "Outputs": Sequence["OutputTypeDef"],
+        "CloudWatchLoggingOptions": Sequence["CloudWatchLoggingOptionTypeDef"],
         "ApplicationCode": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -480,7 +480,7 @@ InputSchemaUpdateTypeDef = TypedDict(
     {
         "RecordFormatUpdate": "RecordFormatTypeDef",
         "RecordEncodingUpdate": str,
-        "RecordColumnUpdates": List["RecordColumnTypeDef"],
+        "RecordColumnUpdates": Sequence["RecordColumnTypeDef"],
     },
     total=False,
 )
@@ -936,7 +936,7 @@ _RequiredSourceSchemaTypeDef = TypedDict(
     "_RequiredSourceSchemaTypeDef",
     {
         "RecordFormat": "RecordFormatTypeDef",
-        "RecordColumns": List["RecordColumnTypeDef"],
+        "RecordColumns": Sequence["RecordColumnTypeDef"],
     },
 )
 _OptionalSourceSchemaTypeDef = TypedDict(
@@ -956,7 +956,7 @@ StartApplicationRequestRequestTypeDef = TypedDict(
     "StartApplicationRequestRequestTypeDef",
     {
         "ApplicationName": str,
-        "InputConfigurations": List["InputConfigurationTypeDef"],
+        "InputConfigurations": Sequence["InputConfigurationTypeDef"],
     },
 )
 
@@ -971,7 +971,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -998,7 +998,7 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
